#
# spec file for package python-veusz
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define X_display ":98"
%{?sle15_python_module_pythons}
%define modname veusz
Name:           python-veusz
Version:        4.0
Release:        1.1
Summary:        Scientific plotting library for Python
# The entire source code is GPL-2.0+ except helpers/src/_nc_cntr.c which is Python-2.0
License:        GPL-2.0-or-later AND Python-2.0
URL:            https://veusz.github.io/
Source0:        https://files.pythonhosted.org/packages/source/v/veusz/veusz-%{version}.tar.gz
BuildRequires:  %{python_module PyQt6-devel}
BuildRequires:  %{python_module devel >= 3.8}
BuildRequires:  %{python_module numpy-devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module sip-devel}
BuildRequires:  %{python_module tomli}
BuildRequires:  %{python_module wheel}
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  man
BuildRequires:  python-rpm-macros
BuildRequires:  xorg-x11-server-Xvfb
Requires:       python-PyQt6
Requires:       python-numpy
Requires:       veusz-common
Recommends:     python-astropy
Recommends:     python-h5py
Recommends:     veusz
ExcludeArch:    i586
# SECTION For Tests
BuildRequires:  %{python_module astropy}
BuildRequires:  %{python_module h5py}
# /SECTION
%python_subpackages

%description
Veusz is a scientific plotting package, designed to create
publication-ready Postscript/PDF/SVG output. It features GUI,
command-line, and scripting interfaces. Graphs are constructed from
widgets, allowing complex layouts to be designed. Veusz supports
plotting functions, data with errors, keys, labels, stacked plots,
multiple plots, contours, shapes and fitting data.

%package     -n veusz
Summary:        GUI scientific plotting package
Requires:       python3-veusz = %{version}
Requires:       veusz-common
Requires(post): desktop-file-utils
Requires(post): shared-mime-info
Requires(postun): desktop-file-utils
Requires(postun): shared-mime-info
Obsoletes:      veusz3 < %{version}
Provides:       veusz3 = %{version}
BuildArch:      noarch

%description -n veusz
Veusz is a scientific plotting package, designed to create
publication-ready Postscript/PDF/SVG output. It features GUI,
command-line, and scripting interfaces. Graphs are constructed from
widgets, allowing complex layouts to be designed. Veusz supports
plotting functions, data with errors, keys, labels, stacked plots,
multiple plots, contours, shapes and fitting data.

%package -n veusz-common
Summary:        Common example and icons for all python flavors of veusz
BuildArch:      noarch

%description -n veusz-common
Veusz is a scientific plotting package, designed to create
publication-ready Postscript/PDF/SVG output.

This package provides datafiles, examples, and icons used by all
python flavours of veusz.

%prep
%autosetup -p1 -n veusz-%{version}
find -name \*~ | xargs rm -f

# Remove hashbangs from eventually non-executable scripts
sed -E -i "/\#!\/usr\/bin\/env python/d" veusz/veusz_{listen,main}.py

%build
export CFLAGS="%{optflags}"
%pyproject_wheel
%make_build -C Documents/ man

%install
%pyproject_install

# Copy common files to /usr/share/ and...
mkdir -p %{buildroot}%{_datadir}/veusz
cp -pr examples icons %{buildroot}%{_datadir}/veusz/

%{python_expand # ...symlink them back into python_sitearch
rm -fr %{buildroot}%{$python_sitearch}/veusz/{examples,icons}
ln -s -t %{buildroot}%{$python_sitearch}/veusz/ %{_datadir}/veusz/{examples,icons}
}

# Install .desktop, mime and appdata files from upstream tarball
install -Dm0644 support/veusz.appdata.xml %{buildroot}%{_datadir}/appdata/veusz.appdata.xml
install -Dm0644 support/veusz.xml %{buildroot}/%{_datadir}/mime/packages/veusz.xml
desktop-file-install -m 0644 \
  --dir=%{buildroot}/%{_datadir}/applications/ \
  --add-category=2DGraphics \
  support/veusz.desktop

# link main veusz icon also into hicolor-icon-theme dir (for desktop file)
for size in 16 32 48 64 128; do
    odir=%{buildroot}%{_datadir}/icons/hicolor/${size}x${size}/apps
    mkdir -p $odir
    ln -s %{_datadir}/veusz/icons/veusz_${size}.png ${odir}/veusz.png
done
odir=%{buildroot}%{_datadir}/icons/hicolor/scalable/apps
mkdir -p $odir
ln -s %{_datadir}/veusz/icons/veusz.svg $odir/veusz.svg

# install man pages
mkdir -p %{buildroot}%{_mandir}/man1
install -p Documents/man-page/veusz.1 -m 0644 %{buildroot}%{_mandir}/man1

# Remove an unneeded hidden file from documentation
rm Documents/manual/html/.buildinfo

%python_expand %fdupes %{buildroot}%{$python_sitearch}/veusz/

%check
export DISPLAY="%{X_display}"
Xvfb %{X_display} >& Xvfb.log &
trap "kill $! || true" EXIT
sleep 5
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitearch}
$python -B tests/runselftest.py
}

%pretrans
# icons/examples/tests were dirs from previous installations, need to rm these first
if [ $1 -gt 1 ]; then
  %python_expand rm -fr %{$python_sitearch}/veusz/{examples,icons}
fi

%files %{python_files}
%doc README.md AUTHORS ChangeLog
%doc Documents/manual/html
%license COPYING
%{python_sitearch}/veusz-%{version}.dist-info/
%{python_sitearch}/veusz/

%files -n veusz
%license COPYING
%{_bindir}/veusz
%{_datadir}/applications/veusz.desktop
%dir %{_datadir}/appdata
%{_datadir}/appdata/veusz.appdata.xml
%{_datadir}/icons/hicolor/*/apps/veusz.*
%{_datadir}/mime/packages/veusz.xml
%{_mandir}/man1/*

%files -n veusz-common
%license COPYING
%{_datadir}/veusz/

%changelog
* Sun Jun  1 2025 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.0:
  * Update to using Qt6.
  * Documentation updates.
  * Copying SVG or image widgets copies image data.
  * Bug fixes:
  - HDF5 import
  - 3D rotation
  - Swap attributes for 2D data if transposing
  - Hide stderr from embedded usage unless debug=True
  - Fix histogram2d fro normed to density
  - Fix for datasets of different lengths if using
    gap_handling='ignore'
  - Rename nan_handling to gap_handling
  - Continue loading if error in plugins
- Switch to PyQt6 instead of PyQt5 for builds.
- Drop unnecessary update-desktop-file BuildRequires.
* Wed Mar 12 2025 Dirk Müller <dmueller@suse.com>
- use modern python for sle15
* Tue Apr 18 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.6.2:
  * Fix broken resource symlink handling.
- Changes from version 3.6.1:
  * Fix appdata file.
  * Fix issue in setup.cfg.
- Changes from version 3.6.0:
  * Interactive rotation of 3D plots.
  * Add 12-bit rainbow colormap.
  * Fix crash in contour key values.
  * Fix breakage with recent numpy versions due to removal of
    bool.
  * Fix error in colormap sequence.
  * About dialog shows software versions.
  * Rewrite install instructions in INSTALL.md.
  * Fix for Python 3.11 due to opening with universal newlines.
  * Remove use of distutils.
- Drop veusz-numpy1.24.patch: incorporated upstream.
* Fri Jan 13 2023 Ben Greiner <code@bnavigator.de>
- Add veusz-numpy1.24.patch for compatibility with NumPy 1.24
* Tue Dec  6 2022 Dirk Müller <dmueller@suse.com>
- update to 3.5.3:
  * Fix missing documentation
* Tue Nov  1 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.5.2:
  * Fix broken ChangeLog.
- Changes from version 3.5.1:
  * Fixes for EMF generating code (requires pyemf-3.1).
- Changes from version 3.5.0:
  * Improvements in fitting, including:
  - Assume absolute errors by default.
  - Introduce minimum and maximum fit ranges.
  - Add setting to give default error value and type
    (absolute/relative).
  - Plugin fixes, renaming --plugin to --veusz-plugin option.
  - Bug fix for broken axis drawing.
  - Mirrored axis bug fix.
  - More keyboard shortcuts.
  - Fix build system to use sip-build, which works with recent SIP
    versions.
  - Change high DPI scaling policy.
  - Support _FillValue and missing_data attributes in HDF5 files
    for NetCDF.
- Drop upstreamed patches:
  * python-veusz-correct-platlib-dir.patch.
  * veusz-sip65.patch.
- New BuildRequires: python-tomli.
- Re-work common data installation:
  * Drop out-of-source icon veusz_256.png: Desktops now support
    rendering svg icons directly.
  * Split out a separate -common package for example, icon, and
    test files common to all python flavours; install these to
    %%{_datadir}/veusz and symlink these to %%python_sitearch dir as
    veusz looks for these files in this location.
  * Require veusz-common package from python flavours packages.
  * Make updates from dir to symlinks possible by rm-ing dirs from
    previous installs (%%pre section).
- Clean up trailing spaces from old changelog entries.
- Run full gamut of tests for %%check; needs BuildRequires:
  xorg-x11-server-Xvfb.
* Sat Sep 24 2022 Atri Bhattacharya <badshah400@gmail.com>
- Restore multi flavour builds for all supported python3 flavours.
- Add python-veusz-correct-platlib-dir.patch: Ensure consistent
  platlib path on all python3 flavours by using sysconfig module
  direclty. N.B.: Patch to be applied after Patch1
  [gh#veusz/veusz#627].
- Make builds for openSUSE < 1550 unresolvable — rather than
  failing — by requiring python >= 3.8 for builds.
* Fri Aug 19 2022 Ben Greiner <code@bnavigator.de>
- Fix obsoletion of flavored package
* Thu Aug 18 2022 Ben Greiner <code@bnavigator.de>
- Add veusz-sip65.patch gh#veusz/veusz#595: fix build with SIP 6.5
- Remove multiflavor build: This application only needs the primary
  python3 flavor.
* Tue Dec 28 2021 Ben Greiner <code@bnavigator.de>
- Fix build requirements: This one actually uses SIP >=5 now.
- Clean up unused python2 expressions in specfile
* Wed Oct 27 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.4:
  * Font styles can be chosen.
  * Add setting to specify minor ticks in axis.
  * Add setting to ignore NaN values in point plotter, rather than
    breaking lines.
  * Add copy and paste of images.
  * Add embedding SVG graphics.
  * New tight-Bezier line style.
  * Add hide icon (eye) in settings and grey tabs as appropriate.
  * Add \ddot latex command.
  * Axis auto ranges (e.g. 5-95%%) can now have decimals.
  * Filename set after Load().
  * Fix renaming 2D datasets.
  * Fix for blank dataset output names in dataset plugin.
  * Fix for crash in QDP plugin.
  * Linux dark mode improvements.
  * Font foundry name removed from SVG files.
  * Add page colour or fill setting.
  * Change default xy plotter marker size and fill colour for new
    documents.
  * Add function widget global colour setting.
* Fri Feb 19 2021 Markéta Machová <mmachova@suse.com>
- veusz should need primary python3 binary
* Mon Feb  8 2021 Markéta Machová <mmachova@suse.com>
- %%ifpython3 does not work with multi-build python
* Mon Jan 18 2021 Atri Bhattacharya <badshah400@gmail.com>
- Disable for python36: dependency python-astropy does not build.
* Thu Dec 10 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.3.1:
  * New tools for zooming into plot on click, zooming out, moving
    plot center and resetting plot axes.
  * Double clicking on axis range resets endpoint to Auto.
  * Add key entries for histo widget.
  * Python 3.10 prerelease fixes.
  * Fix for reproducible builds.
* Sun Nov 29 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.3:
  * New histogramming widget (histo).
  * Add keyboard shortcut for showing/hiding widgets (Ctrl+[ and
    Ctrl+]).
  * New security model allows running arbitrary code for documents
    in allowed locations.
  * Allow Python-level module imports.
  * New separate lo and hi error bar styles (gh#veusz/veusz#428).
  * Use same colour for key title as key text
    (gh#veusz/veusz#414).
  * Add preferences for number of significant figures in picker.
  * New colormaps: inferno, magma, moreland, parula, plasma and
    viridis.
  * Add CurrentPath() API command to get current widget path.
  * Add dataset operations for reversing and subtracting dataset
    maximum.
  * Now supports building using sip5.
  * Bugfix for values in boxplots (gh#veusz/veusz#455).
  * Add setting to optionally omit paths in document files.
  * New flight-recorder and histogram examples.
  * Make sure line around arrows is solid (gh#veusz/veusz#429).
  * README is now renamed to README.md.
  * Switch to unsigned long long for widget IDs to fix build.
  * Add multiline FieldTextEdit (gh#veusz/veusz#392) field.
- Switch BuildRequires: python-sip to python-sip4 and add
  BuildRequires: python-sip4-devel to fix unresolvable build
  status for openSUSE < 1550.
- Add python-astropy as BuildRequires (for fits tests) and as
  Recommends for python-veusz.
- Add python-veusz-rpmlintrc file to suppress a warning for
  incorrect EOL encodings in a file which should not be fixed.
- Drop duplicated `AUTHORS` file from the `veusz` pkg: it is
  already a part of the `python-veusz` pkg which is a `Requires`
  for `veusz`.
* Fri Jul 17 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 3.2.1
  * Add \wtilde text command to place a tilde over text
  * Add ability to plot image widget using boxes rather than a bitmap,
    with new drawing mode option
  * Add widget order option in key widget
  * Export dialog now uses multiple threads
  * Python 3.9 compatibility fixes
* Tue Nov 19 2019 Todd R <toddrme2178@gmail.com>
- Update to version 3.1
  + Improvements:
  * Do not print or export hidden pages
  * Allow expressions in dataset of contour widget
  * Allow widgets to be excluded in key (thanks to Alexander Book)
  * Make bezier line better fit data
  * Switch linux binary from x86 -> x86-64 for better compatibility
  + Bug fixes:
  * Compilation fix for PyQt>=5.12 (thanks to Dimitry Shachnev)
  * Ensure fit settings are sorted in output file
  * Fix crash in contour labelling
  * Fix 3D axis crash bug
  * Fix problem with broken axis with null-sized regions
  * Fix issue with 0-sized images in image widget
  * Fix function widget crash with certain plotting range
  * Fix for axis crash with large magnitude ranges
  * Fix CSV importing issues for 2D and ND data
  * Fix zero division error in 2D import
  * Fix crash on importing HDF5 files with variable length text
  * Catch issue with zero range axes
  * Fix crash is using set in dataset expression
  * Fix crash when moving line coordinates
  * Remove deprecation warnings when compiling with recent Qt versions
* Mon Jul 29 2019 Todd R <toddrme2178@gmail.com>
- Drop broken python2 version.
* Fri Jun 14 2019 Atri Bhattacharya <badshah400@gmail.com>
- Disable builds for i586 as they no longer succeed.
* Mon Jul 23 2018 jeremy@jeremysanders.net
- Update to version 3.0.1
  * Adds 3D support
  * Adds SVG DPI options
  * Arbitrary page lists can be exported
  * Fix zoom for polar, ternary and broken axis plots
  * Fix image embedding
  * Fix fractions and percentages units in polar plot
  * Prevent crash in point picker with non-finite points
  * Adds --export-option command line option
  * Fixes for arrow positions
  * Support datetime64 and string characters in npy/npz
- Re-enable tests, as no longer needs Xvfb
- Use -fno-strict-aliasing for python2
* Sun Dec 10 2017 badshah400@gmail.com
- Update to verion 2.1.1
  + Bug fixes:
  - Fixes an error when exporting a plot with dotted/dashed
    lines to EMF format.
  - Errors when using dataset, tools or import plugins are
    solved.
  - Command line argument handling has been rewritten, fixing an
    encoding issue in Windows where some filenames (e.g.
    Chinese) would not open when double-clicked.
  - Splash screen is now hidden after a time period, so it does
    not obscure dialog boxes.
  - Reintroduce code to use the deprecated sipconfig if possible
    when building to get details of the SIP installation.
- Build against PyQt5; adapt BuildRequires/Requires appropriately.
- Drop manually setting exec permissions to appropriate files;
  these are now taken care of by the installer.
- Temporarily disable tests for x86_64: they get indefinitely
  stuck for unknown reasons, while tests for i586 succeeds without
  problems.
* Fri Aug 11 2017 toddrme2178@gmail.com
- Implement singlespec version
- Fix shebangs
* Tue May 16 2017 badshah400@gmail.com
- Update to version 1.26.1:
  + Change homepage in program to new site
    https://veusz.github.io/.
  + Change new version checking to use veusz.github.io.
- Update URL to new veusz home page, and source URL to github
  release tarball.
* Mon May 15 2017 badshah400@gmail.com
- Update to version 1.26:
  + Add color themes and automatic coloring of widgets.
  + Custom color definitions.
  + Improved custom definition dialog box.
  + Fix loading translator via command line.
  + Show horizontal error lines/fills in key.
  + Use iMinuit if available for fitting.
  + Fix for dataset plugins returning nD datasets.
  + Add editable automatic axis range, including support for
    shrinking range (-X%%), percentage ranges (X-Y%%) and limits
    (<X%% and >Y%%).
  + Fix for key if invalid dataset.
  + For log scaling on image widget, show invalid values as being
    transparent.
* Tue Jan 17 2017 badshah400@gmail.com
- Update to version 1.25.1:
  + Remove left in print statement and fix comment.
- Changes from version 1.25:
  * Features:
    + Add n-dimensional dataset support
    + Add GetColormap command to return RGBA values
    + Add Colormap sequence plugin for choosing colors of widgets
    + Fill above/below setting shown in key for xy widget
    + Add Covariance widget for plotting covariance ellipses
    + Add lineup, linedown, lineleft and lineright markers
    + Add lineup, linedown and lineextend arrows
  * Bug fixes:
    + Fix pick indices if non-finite values in data
    + Fix drag and drop of files into Veusz on Windows
    + Raise exception if functions in console request input, avoiding
    hang
    + Initialise unsafe_mode, in case Veusz used in PyQt embedding
    + Fix crash if setting default setting in default setting window
    + Fix crash in Clone() command on python3
- Drop all Xvfb related definitions; we are not installing the
  GUI and not running %%check for python2 builds any more.
* Wed Aug  3 2016 badshah400@gmail.com
- Drop the GUI application (this is still available from the
  python3 compiled version python3-veusz), leaving only the python
  modules.
* Fri Jul 15 2016 badshah400@gmail.com
- Move all application related files to subpackage veusz, leaving
  only actualy python modules in the python-veusz pkg.
- Hardlink icons from pixmaps/veusz to hicolor-icon-theme, as
  symlinked icons lead to appstream-builder being unable to
  detect them and vetoes the application consequently.
* Sat May  7 2016 badshah400@gmail.com
- Update to version 1.24:
  + Text labels can now include Python expressions inside %%{{ }}%%
  + Added built-in functions DATE([fmt]), TIME([fmt]), FILENAME()
    and BASENAME() when evaluating expressions, which are useful
    when used in labels
  + Added Python dictionary ENVIRON when evaluating expressions,
    to obtain values from environment variables
  + Added DATA(name, [part]) function to expression environment
    for accessing values from datasets, useful for function
    evaluation or labels
  + Added SETTING(path) function for expression evaluation to
    obtain values of settings
  + Added ESCAPE(text) function to environment, which allows LaTeX
    special characters to be displayed in labels
  + Add fractions and percentages units to polar plot
  + Allow number of spokes to be varied in polar plot
  + Widgets can be clicked holding down shift or ctrl, to add or
    toggle their selection
  + Add K. Moreland's cool-warm colormap (thanks to S. Richardson)
  + Added further green-map, blue-darkred, blue-darkorange,
    brown-blue and blue-orange colormaps from Oregon geography
    dept.
  + Add logarithm and exponential dataset plugins
  + Add Wipe() command to embedding interface to clear document
  + Add File->Reload menu option to reload from saved document
  + Add tooltip to items in FieldWidget showing widget path
  + Bux fixes:
  - Fix transparency with bar plot
  - Use getcwdu() for python2 to avoid bugs combining paths
  - Handle inf/nan when converting to human readable form in plots
  - Fix CreateHistogram on command line without binparams
    parameter
  - Handle empty 2D dataset import with grid at edge enabled
  - Do not allow error bars on imported CSV non-numeric data
  - Handle missing argument in \size
  - For data edit dialog, allow 1D dataset to replace 2D dataset
  - Crash if zoom to be height when height is zero
  - Fix problem with 2D import if error message is in unicode
  - With axis-function widget catch result if greater than 1
    dimension
  - Fix cloning for datasets with / in name
  - Fix crash in embedding if plot window closed while rendering
    in progress
  + Clean up mess (__pycache__ dirs containing python object files
  without corresponding sources) after %%clean.
* Sun Apr  3 2016 badshah400@gmail.com
- Add BuildRequires and Requires on python-h5py: enables the
  hdf5 data import module in the application.
- Run specfile through "spec-cleaner -m" for cleanup.
* Fri Jun 19 2015 badshah400@gmail.com
- Update to version 1.23.1:
  + Enable compression in exported files.
  + Fix saving histogram datasets.
  + Add option to "thin" error bars plotted.
  + Fix label colour in contour labelling.
  + Remove use of deprecated Qt functions.
  + Fix clone widget tools plugin.
  + Fix EPS/PDF crash with broken axis widget.
  + Do not crash filter plugin if using date datatype.
  + Avoid crashes in normalise, subtract minimum and divide
    maximum plugins.
  + Avoid crash in image widget.
  + Avoid issue in identifying spacing in 1D->2D conversion.
  + Add Gnuplot 2D data import plugin.
  + When loading data from import plugins, provide default values.
  + Remove some deprecated Qt uses.
  + Fix issue when plotting non-plain datasets with nan values.
* Sun Apr 19 2015 badshah400@gmail.com
- Update to version 1.23:
  + Add new export dialog box which can export multiple pages and
    modify the export options.
  + Add new dataset filtering dialog.
  + Add cubehelix() functional colormap.
  + Add -stepN suffix for colormaps to make arbitrary numbers of
    steps.
  + Fix incorrect colors in log images and log color scales.
  + Fix unsafe commands not being run.
  + Fix incorrect use of None in (x,...) pattern.
  + Catch crash if plotting nan/inf value in log space.
  + Fix getData in dataset plugin for dimensions=2
  + Catch error in too large float to date time conversion.
  + Catch disappeared file during import.
  + Index error fixed in pickable.
  + Catch error in data edit dialog if 2d dataset size changes.
  + If root widget is selected with others, do not error on hide.
  + Fix undo for dataset histogram with a single output dataset.
  + Fix error resizing ellipse with a tuple width, height or
    position setting.
  + Only use finite values in histogram.
  + Rewrite Line/FillSet setting controls for internal consistency
    and to fix new style extended fills.
  + Do not crash with log date-time axes.
  + Also ignore non-finite values when fitting with minuit.
  + Avoid syntax error with invalid colormap.
  + Updates to setup.py and desktop files.
  + Recreate dataset now works if dialog hasn't been opened
    already.
  + Restore dock layout when using Python3
  + Fix undo after loading stylesheet/custom definitions.
  + Support unicode example filenames.
  + Clip bezier lines to avoid problems with log axes.
* Mon Mar  2 2015 toddrme2178@gmail.com
- Reorganize files so the python 2 and python 3 versions of the
  package do not conflict
- Split gui stuff into veusz subpackage per python package naming
  guidelines.
* Sun Oct 19 2014 badshah400@gmail.com
- Update to version 1.22:
  + Add option to ignore white space following delimiters when
    importing CSVs
  + Allow x/yedge and x/ycent to be inverted to change data order
    when import 2D data
  + Rewrite of widget tree internals to fix miscellaneous bugs
  + Optionally use astropy for SAMP
  + Add setting to extend the python import path
  + Add option to select widgets with same name on page
  + Resize rectangular shapes keeping other corners fixed; old
    symmetric resize behaviour is retained if shift is pressed.
* Sat Aug 30 2014 badshah400@gmail.com
- Update to version 1.21.1:
  + Add swap option on keys, swapping symbol and text
  + Bug fixes:
  - Fix missing labels if colorbar out of plot
  - Preserve tags when reloading datasets
  - Handle nan/inf/-inf when as value in UI
  - Remove dependence on pyqtconfig in build system
  - Handle errors properly in 2D CSV read
  - Do not crash if selecting siblings of document widget
  - Fix accidental modification of data by line widget
  - Improve PDF bounding box rounding to prevent chopping near
    edge
  - Fix function plotter in embedding
  - Fix astropy version checking
  - Fix crash for error bar in CSV with blank previous column
- Drop python-veusz-test-disable-contour_labels.patch; patch
  incorporated upstream.
* Sun May  4 2014 badshah400@gmail.com
- Update to version 1.21:
  + Add HDF5 saved document format
  + Add filled curve error bar style
  + Add fill left/right options for point plotter
  + Add filetype filters to import dialog file browser dialog
  + In file completer in import dialog, use selected tab as filter
  + Move code to use PyQt new style signals
  + Add a master color setting for xy point and nonorthpoint plot
  + Line labelling algorithm much improved in contour plots, which
    rotates text to match line angle and avoids label overlaps
  + More accurate axis tick label bounding boxes, allowing rotated
    labels to be placed close together
  + Add reflection and rotation options to vector field widget
  + Switch to scientific notation earlier when showing float
    settings
  + Bug fix:
  - Direction combo did not work in import dialog
  - Saving text datasets did not work in Python3
  - Fix partial dataset evaluation issue when loading documents
  - 2D non-regular pixel spaced images give error if clipped in
    y
  - Handle Unicode quoted characters in simple text data files
  - xcent/ycent in Dataset2D import plugins were ignored
  - promote_tab broken for import plugins
  - Full screen view when all pages are deleted
  - Crash with empty dataset and boxplot widget
  - Fix copy and paste of datasets
  - Python 3 resizing axis bug
  - Crash if picking/zooming on document with no pages
  - Crash if reediting histogram dataset with blank output entry
  - Use end of text formatting string beyond format specifier
  - When writing SVG text as text, use xml:space="preserve" to
    avoid missing whitespace
  - Embedding socket issue on Python 3.4+
- Add python-veusz-test-disable-contour_labels.patch to disable a
  test that unnecessarily causes build failures; patch came from
  upstream.
* Wed Feb 12 2014 badshah400@gmail.com
- Update to version 1.20.1:
  + Include free-desktop appdata, MIME and desktop files
  + When plotting xy widget filled error regions, plot line on top
  + Bug-fixes:
  - Fix embedding interface startup problem in 1.20
  - Additional embedding interface fixes for Python 3
  - Fix crash in tutorial if flashing widget deleted
  - Fix polar plot crash with reverse minumum and maximum radii
  - Fix crash when changing range of broken axes interactively
  - Fix object deletion crash in setting menu
  - Check output dataset is not same as an input for histograms
  - Fix for compilation on Qt 4.6
  - Catch socket errors on embed client
  - Fixes for formatting strings, including fixes for arguments
    of the extended %%Vg format and properly supporting %%%%
  - When restoring window position, do not restore offscreen
- Packaging changes:
  + Drop macros for EOL openSUSE versions in spec file
  + Upstream bundles desktop and MIME files, install these
    instead of external desktop and MIME files (use
    desktop-file-install to add categories to .desktop file)
  + Also package appdata bundled with upstream tarball.
* Fri Jan 17 2014 badshah400@gmail.com
- Update to version 1.20:
  + Add HDF5 file data import
  + Allow expressions to be edited for linked 2D datasets
  + Add support for 2D datasets with irregular gridpoints
  + Add 2D data CSV import
  + Allow safe renaming of linked datasets
  + Support importing text from FITS files
  + Bug fixes:
  - When capturing data from a file/named pipe, do not stop
    when no more data are available
  - Fixes mangling of text in saved files using Windows binary
  - Fix encoding for standard file import
  - Fix FITS import for python3
* Fri Nov 29 2013 badshah400@gmail.com
- Update to 1.19.1:
  + Add option to disable scaling of marker border with point
    scaling
  + Implement label at-minimum/at-maximum for ternary plot
  + Add border and background fill settings for text label widget
  + Enable FITS support with astropy
  + Bug fixes:
  - Fix broken drag and drop in documents
  - Fix deleted C/C++ object crash when using undo and in
    tutorial
  - Fix compilation in MSVC for Python 3
  - Remove warning/error in compilation in gcc in SUSE
  - Add Python version classifiers
  - Fix document icons in Windows binary
  - Error bars can be plotted incorrectly for histogrammed data
- Drop python-veusz-fix-histogram-errorbars.patch; fix
  incorporated by upstream.
* Wed Nov 27 2013 badshah400@gmail.com
- Add python-veusz-fix-histogram-errorbars.patch to fix bnc#852537
  (upstream bug gh#jeremysanders/veusz#49) which led to incorrect
  bars for histograms; patch taken from upstream and applied to
  fit version 1.19.
* Mon Nov 18 2013 badshah400@gmail.com
- Update to version 1.19:
  + Make code compatible with python3
  + Separation of python module and resources in source package
    (packagers may need to consult INSTALL)
  + Move to v2 of PyQt API
  + Remove deprecated numpy API from helpers module
  + Allow FITS dataset names to be blank if prefix/suffix are not
  + New ast-based code security checker
  + Picker uses 1-based index for consistency
  + Allow non-text datasets to be used for labels
  + Add number->text conversion dataset plugin
  + Add binning dataset plugin
  + Add notes properties to document, pages and graphs
  + Allow more significant figures in float values
  + Intelligent choice of significant figures when interactively
    changing axis range
  + Decrease minimum range of axis
  + Add notes setting to document, pages and graphs
  + Bug fixes:
  - Fix crash if other linked axis not initialized
  - Fix crash if trying to edit non-editable datasets
  - Make ignore exception work in error reporting dialog
  - Renaming datasets, widgets and editing data now allow
    original text to be edited, rather than being cleared
  - Fix line positions on broken axes
  + Packaging changes:
  - Implement %%check section for self tests (requires
    xorg-x11-server) as recommended by upstream
  - Use symlinks for resources (icons, etc.) wherever possible
    instead of editing source-code to modify resource directory
  - Also install COPYING file in package's resource directory
    (otherwise the About dialog of the application fails to
    display the license).
* Sun Jul  7 2013 badshah400@gmail.com
- Update to version 1.18:
  + Add support for dataset expressions when plotting
  + Add axis-function widget for plotting axes which have a scale
    given by a function, or are linked to a different axis via a
    function
  + Add stepped colour maps
  + Support editing multiple datasets simultaneously in editor
  + Add setting to fix aspect-ratio of graphs
  + Add 'vcentre' line step mode for vertical step plots
  + Add internal margin setting for grids to separate sub-plots
  + Add pixel, pixel_wcs, fraction and linear_wcs FITS import
    coordinate system modes
  + Add drop down toolbar button menu to create axis widgets
  + More efficient widget dependency resolution
  + Bug fixes:
  - Fix reversed 'broken'-axes
  - Do not always draw axes above other widgets (fixes problem
    with key below axis)
  - Fix use of transparency image when plotting non-square
    images
  - Allow lists passed as xrange and yrange to create 2D dataset
  - Fix FieldBool positioning for plugins
  - QDP import: fix "no" values when used mixed with numbers
  - Remove warning of log images with zeros
  - For embedded mode, always return string for __repr__
* Tue Apr 16 2013 badshah400@gmail.com
- Update to 1.17.1:
  + Allow coloured points for non-orthogonal plots (polar,
    ternary)
  + Remove unnecessary exception data
  + Bug fixes:
  - Fix Print dialog
  - Fix command-line "Print" command
  - Fix duplicate axes drawn in grid
  - Fix crash adding empty polar plot
* Fri Mar 29 2013 badshah400@gmail.com
- Update to version 1.17:
  + Add new broken axis widget with gaps in the numerical sequence
  + Grid lines are plotted always under (or over) the data
  + Shift+Scroll wheel scrolls left/right (thanks to Dave Hughes)
  + Polar plots can have a "minimum" radius and log axes
  + Many more LaTeX symbols added
  + Add SAMP/VoTable support (thanks to Graham Bell)
  + New shifted-points xy line mode, which plots a stepped line
    with the points shifted to lie between the coordinates given
  + Points can be picked to console and/or clipboard
    (thanks to Valerio Mussi)
  + Allow reversed ternary plot
  + Bug fixes:
  * Fix unicode characters for \circ and \odot
  * Fix for data type of pickable points
  * Fix sort by group crash bug
  * Many crashes fixed
  * Fix width of key when using long titles/and or multiple
    columns
  * Fix bold and italic output in SVG output
* Wed Jan 23 2013 badshah400@gmail.com
- Use the correct icon-theme-cache post script, this fixes a
  packaging bug that prevented the correct veusz icon from being
  shown on the desktop menu (until gtk-update-icon-cache was run
  manually by the user).
* Mon Jul 23 2012 badshah400@gmail.com
- Install icon files: these got removed during the previous
  update. This fixes a rather ugly regression from the previous
  build which made the vuesz interface show up with no icons at
  all.
* Tue Jul 10 2012 badshah400@gmail.com
- Update to version 1.16:
  + Experimental MathML support
  + Add upper/lower-left/right arrows
  + Add options to clip text/lines/shapes to graphs
  + Add stacked-area option to bar plot widget
  + Draw stacked bar plots top-down for better overlapping line
    behaviour
  + Axis labels can be placed at left or right of axes, in
    addition to centre
  + Line widget now has length-angle or point-to-point modes,
    better support for only specifying some coordinates.
  + Exception dialog records more detailed traceback
  + Use top level windows for non-modal dialogs, giving minimize
    in window and no always-on-top behaviour
  + Zero length vectors and arrows in vector fields are not
    plotted
  + Add support for strings to be translated
  + Add "Sort" dataset plugin
  + Add "Histogram 2D" dataset plugin
  + Add "Divide by Maximum" and "Normalize" dataset plugins
  + Support for *args and **kwargs for custom functions
  + Custom colormaps can be defined in the custom editing
    dialog
  + Bug fixes:
  - Use correct definition of 1pt = 1/72in
  - Workaround for splash screen problem
  - Fix numerous problems reported by pyflakes
  - Histograms fail when saved
  - Fix plot with nan functions
  - Fix failure of self tests on ARM platforms
  - Force pages/documents to have physical sizes
  - Fix crash if deleting multiple datasets in data edit dialog
  - Check dimensions of datasets in SetData
  - Handle better zero bytes in data files
  - Fix error if page size zero
  - Fix error if vector baselength is zero
  - If dataset plugin parameter not given in saved file, use
    default
  - Fix crash for axes with same minimum and maximum
  - Fix CSV import problem when same dataset has multiple types
  - Thinning markers works when using marker sizes / colors
  + Package icons in the hicolor icon directory; use BuildRequires:
  hicolot-icon-theme for required post scriptlets
  + Install 256x256 icon to make application icon look better on the
  gnome-shell
  + Depend on the right version of SIP ABI (prevents issues like
  bnc#711890 from happening)
  + Add a Provides: veusz = %%{version} to spec file.
* Sun Jul  8 2012 scorot@free.fr
- fix build for SLE_11_SP2
* Fri Apr  6 2012 badshah400@gmail.com
- Update to version 1.15 (for complete list of changes please see
  http://home.gna.org/veusz/releasenotes/1.15.txt):
  + Major changes:
  - Improved hatching
  - Added options to extend axes by 2, 5, 10 and 15%% of data
    range
  - Full screen graph view mode
  - Ctrl+MouseWheel zooms in and out of plot
  - New dataset plugins: Linear interpolation, Cumulative value,
    Rolling average, Subtract mean / minimum
  - Allow grid widgets to be placed in grid widgets
  - Allow multiple datasets to be selected in dataset browser
  - Allow tagging of datasets and allow datasets be grouped by
    tags in dataset browser
  - Allow text to be written as text in SVG, rather than curves
  - Add DBus interface to program, if DBus is installed
  - 2D QDP support
  - Add title option for keys.
  + Bug fixes:
  - Use / rather than \ for path separator in saved file names
  - Trap case where nan values could be plotted
  - Fix error if website not accessible in exception dialog
  - Crash when min and max of axes are too similar
  - Fix clipping of paths after transform in SVG files
  - Fix crash in picker
  - Fix crash if duplication of characters in CSV date format
  - Fix crash in tool tip in dataset browser
  - Fix GlobalColor error (on certain dark color sets)
  - Fix blocked data import if no descriptor
  - Fix crash if log contours and minimum is zero
  - Bug fix https://bugzilla.redhat.com/show_bug.cgi?id=800196.
  + Several minor fixes.
* Sat Feb 25 2012 scorot@free.fr
- fix build for SLE-11
* Tue Nov 29 2011 badshah400@gmail.com
- Minor spec file changes:
  + Use Name: python-veusz instead of Name: python-%%{pyname}
  + Modify License tag in accordance with spdx specifications
* Tue Nov 29 2011 badshah400@gmail.com
- Update to version 1.14
  + Added interactive tutorial
  + Points in graphs can be colored depending on another dataset
    and the scale shown in a colorbar widget
  + Improved CSV import
  - better data type detection
  - locale-specific numeric and date formats
  - single/multiple/none header modes
  - option to skip lines at top of file
  - better handling of missing values
  + Data can be imported from clipboard
  + Substantially reduced size of output SVG files
  + In standard data import, descriptor can be left blank to
    generate dataset names colX
  + Axis plotting range can be interactively manipulated
  + If axis is in date-time format, show and allow the min and
    max values to be in date-time format
  + ImageFile widget can have image data embedded in document
    file
  + Fit widget can update the fit parameters and fit quality to a
    label widget
  + Allow editing of 2D datasets in data edit dialog
  + Add copy and paste dataset command to dataset browser context
    menu
  + Bug Fixes:
  - Fix initial extension in export dialog
  - Fix crash on hiding pages
  - Fixed validation for numeric values
  - Position of grid lines in perpendicular direction for non
    default positions
  - Catch errors in example import plugin
  - Fix crash for non existent key symbols
  - Fix crash when mismatch of dataset sizes when combining 1D
    datasets to make 2D dataset
  + Minor changes (see
    http://home.gna.org/veusz/releasenotes/1.14.txt for a full
    list).
- Spec file changes:
  + Use source provided tarballs (tar.gz) instead of
    recompressing
* Fri Aug 19 2011 badshah400@gmail.com
- Update to version 1.13
  + Graphs are rendered in separate threads for speed and a
    responsive user interface
  + A changed Graph is rendered immediately on document
    modification, improving latency
  + A new ternary plot widget is included
  + Size of pages can be modified individually in a document
  + Binary data import added
  + NPY/NPZ numpy data import added
  + Axis and tick labels on axes can be rotated at 45 deg
    intervals
  + Labels can be plotted next to points on non-orthogonal plots
  + Add an option for DPI of output EPS and PDF files
  + Several minor improvements (see ChangeLog file)
  + Bug fixes:
  - Images plotted when axes are inverted are inverted too
  - Fixed crash when selecting datasets for plotting in the
    popup menu
  - Fixed picker crashes with a constant function
  - 2D dataset creation using expressions fixed
  - CSV reader treated dataset names ending in + or -
    incorrectly
  - unique1d function no longer available in numpy
* Fri Aug  5 2011 badshah400@gmail.com
- Update to version 1.12:
  + Multiple widgets can now be selected for editing properties
  + Add Edit->Select menu and context menu for above
  + Added context menu on dataset browser for filenames to reload,
    delete or unlink all associated datasets
  + New tree-like dataset browsing widget is shown in data edit
    dialog
  + Importing 1D fits images is now supported
  + Date / time data has its own dataset type
  + The data edit dialog box can create or edit date/time data in
    human-readable form
  + Add LaTeX commands \cdot, \nabla, \overline plus some arrows
  + Inform user in exception dialog if a new version is available
  + Add linevertbar and linehorzbar error bar styles
  + Bug fixes:
  - Fix crash on filling filled error regions if no error bars
  - Remove grouping separator to numbers in locale as it creates
    ambiguous lists of numbers
  - Undo works properly for boolean and integer settings
  - Prevent widgets getting the same names when dragging and
    dropping
  - Hidden plot widgets are ignored when calculating axis ranges
  - Combo boxes are now case sensitive when displaying matches
    with previous text
  - Fix errors if plotting DatasetRange or Dataset1DPlugin
    datasets against data with nan values
  - Fix division by zero in dataset preview
  - Do not leave settings pointing to deleted widgets after an
    undo
  - Fix errors when using super/subscripts of super/subscripts
  - Fix crash when giving positions of bar plot and labels
  - Do not allow dataset names to be invalid after remaining
  - Several EMF format bug fixes
  - Stop crash when contouring zero-sized datasets
- Changes from version 1.11:
  + New data point picker for finding coordinates of points on plot
  + New data navigator window for filtering, sorting and examining
    dataset statistics
  + ".." button next to dataset settings pops up data navigator for
    choosing datasets
  + Data fitting can now use PyMinuit, giving error estimates
  + Console history now uses currently entered characters to select
    lines from history
  + New self test script, comparing graph output with expected
    output
  + Put superscripts and subscripts above each other when
    formatting
  + Key entries can have multiple lines (using \\)
  + Option to treat blanks as data items in CSV files
  + Locale support added for number formatting
  - Can use current locale or US/English in documents
  - Can use US/English or current local in user interface
  + Contours avoid missing (nan) values
  + Several bug fixes (see ChangeLog file for details)
- Spec file cleanup:
  + Removed BuildRequires: python-distribute to allow building
    with openSUSE 11.4 and earlier
  + Use %%suse_update_desktop_file macro to install .desktop entry
  + Miscellaneous minor modifications
* Sun Dec 19 2010 ocefpaf@yahoo.com.br
- First OpenSuse release
